import { useFetch } from '@/hooks/useFetch';
import { PageResult,PageMoreResult } from '@/utils/page';
import {
    CategoryListParams,
    CategoryListResult,
    EmployeeSearchParams,
    EmployeeDetailParams,
    EmployeeSearchResult,
    UserLoginParams,
    UserLoginResult,
    UserPasswordParams,
    UserInfoParams,
    UserInfoResult,
    UserBalanceResult,
    ChatSubmitParams,
    ChatSubmitResult,
    ChatMessageParams,
    ChatMessageResult,
    ChatSessionParams,
    ChatSessionResult,
    ChatSessionDeleteParams,
    ChatSessionRenameParams
} from '@/utils/clientsApis';
import {Result} from '@/utils/result';

/**
 * 获取分类列表
 */
export const getCategoryList = (params: CategoryListParams): Promise<Result<PageResult<CategoryListResult[]>>> => {
    const fetchService = useFetch();
    return fetchService.post('/category/list', { body: params });
};

/**
 * 获取智能体列表
 */
export const getEmployeeSearch = (params: EmployeeSearchParams): Promise<Result<PageResult<EmployeeSearchResult[]>>> => {
    const fetchService = useFetch();
    return fetchService.post('/employee/search', { body: params });
};

/**
 * 获取智能体详情
 */
export const getEmployeeDetail = (params: EmployeeDetailParams): Promise<Result<EmployeeSearchResult>> => {
    const fetchService = useFetch();
    return fetchService.post('/employee/detail', { body: params });
};

/**
 * 前台用户登陆
 */
export const userLogin = (params: UserLoginParams): Promise<Result<UserLoginResult>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/user/login', { body: params });
};

/**
 * 前台用户修改密码
 */
export const userPassword = (params: UserPasswordParams) => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/user/password', { body: params });
};

/**
 * 前台用户修改个人信息
 */
export const updateUserInfo = (params: UserInfoParams) => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/user/update', { body: params });
};

/**
 * 查看用户信息
 */
export const getUserInfo = (): Promise<Result<UserInfoResult>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/user/info');
};

/**
 * 查看用户积分
 */
export const getUserBalance = (): Promise<Result<UserBalanceResult>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/user/balance');
};

/**
 * 聊天提交内容
 */
export const chatSubmit = (params: ChatSubmitParams) => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/chat/submit', { body: params });
};

/**
 * 查询会话下的聊天历史
 */
export const getChatMessage = (params: ChatMessageParams) : Promise<Result<PageMoreResult<ChatMessageResult[]>>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/chat/message', { body: params });
};

/**
 * 聊天会话列表
 */
export const getChatSession = (params: ChatSessionParams) : Promise<Result<PageMoreResult<ChatSessionResult[]>>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/chat/session', { body: params });
};

/**
 * 聊天会话删除
 */
export const deleteChatSession = (params: ChatSessionDeleteParams): Promise<Result<null>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/chat/session/delete', { body: params });
};

/**
 * 聊天会话重命名
 */
export const renameChatSession = (params: ChatSessionRenameParams): Promise<Result<null>> => {
    const fetchService = useFetch();
    return fetchService.post('/gpts/chat/session/rename', { body: params });
};
