import { NextUIProvider } from "@nextui-org/react";
import { Inter } from "next/font/google";
import type { Metadata, Viewport } from "next";
import "./globals.scss";
import { ThemeProvider } from "@/providers/ThemeProvider";
import { GlobalProvider } from "@/providers/GlobalProvider";

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: `${process.env.SITE_TITLE}`, // 网站标题
  description: process.env.SITE_DESCRIPTION, // 网站描述
  applicationName: process.env.PROJECT_NAME, // 应用名称
  authors: { name: process.env.AUTHOR_NAME, url: process.env.AUTHOR_BLOG }, // 网站作者
  keywords: process.env.SITE_KEYWORDS, // 网站关键词
  icons: {
    icon: "/favicon.ico",
    shortcut: "/favicon-16x16.png",
    apple: "/apple-touch-icon.png",
  },
};

export const viewport: Viewport = {
  themeColor: [
    { media: "(prefers-color-scheme: light)", color: "#fff" },
    { media: "(prefers-color-scheme: dark)", color: "#000" },
  ],
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html suppressHydrationWarning>
      <body className={inter.className}>
        <NextUIProvider>
          <GlobalProvider>
            <ThemeProvider>{children}</ThemeProvider>
          </GlobalProvider>
        </NextUIProvider>
      </body>
    </html>
  );
}
