"use client";
import { useRouter } from "next/navigation";
import Image from "next/image";
import { useGlobalContext } from "@/providers/GlobalProvider";

export default function Header() {
  const router = useRouter();
  const { menuIndex } = useGlobalContext();

  return (
    <>
      <div className="relative h-full">
        <div className="flex flex-col items-center space-4 select-none">
          <div
            className={`p-1 my-2 rounded-md text-center ${
              menuIndex == 1
                ? "bg-blue-50 dark:bg-blue-950 text-[#0061ff]"
                : "text-gray-500 dark:text-gray-400 hover:text-gray-900 dark:hover:text-white hover:bg-gray-50 dark:hover:bg-gray-800"
            } cursor-pointer`}
            onClick={() => router.push("/dialogue.html")}
          >
            <Image
              src="/icons/icon-talk.svg"
              alt="聊天"
              width={50}
              height={50}
            />
            <p className="text-sm text-center py-1">对话</p>
          </div>
          <div
            className={`p-1 my-2 rounded-md text-center ${
              menuIndex == 2
                ? "bg-blue-50 dark:bg-blue-950 text-[#0061ff]"
                : "text-gray-500 dark:text-gray-400 hover:text-gray-900 dark:hover:text-white hover:bg-gray-50 dark:hover:bg-gray-800"
            } cursor-pointer`}
            onClick={() => router.push("/")}
          >
            <Image
              src="/icons/icon-app.svg"
              alt="应用"
              width={50}
              height={50}
            />
            <p className="text-sm text-center py-1">应用</p>
          </div>
          <div
            className={`p-1 my-2 rounded-md text-center ${
              menuIndex == 3
                ? "bg-blue-50 dark:bg-blue-950 text-[#0061ff]"
                : "text-gray-500 dark:text-gray-400 hover:text-gray-900 dark:hover:text-white hover:bg-gray-50 dark:hover:bg-gray-800"
            } cursor-pointer`}
            onClick={() => router.push("/vip.html")}
          >
            <Image
              src="/icons/icon-vip.svg"
              alt="会员"
              width={50}
              height={50}
            />
            <p className="text-sm text-center py-1">会员</p>
          </div>
          <div
            className={`p-1 my-2 rounded-md text-center ${
              menuIndex == 4
                ? "bg-blue-50 dark:bg-blue-950 text-[#0061ff]"
                : "text-gray-500 dark:text-gray-400 hover:text-gray-900 dark:hover:text-white hover:bg-gray-50 dark:hover:bg-gray-800"
            } cursor-pointer`}
            onClick={() => router.push("/help.html")}
          >
            <Image
              src="/icons/icon-question.svg"
              alt="帮助"
              width={50}
              height={50}
            />
            <p className="text-sm text-center py-1">帮助</p>
          </div>
        </div>
        <div className="flex flex-col items-center space-4 select-none inset-x-0 mt-20">
          <div
            className={`w-full my-2 py-3 rounded-md text-center text-gray-900 dark:text-gray-500 bg-gray-50 dark:bg-gray-800 border border-slate-200 dark:border-slate-700`}
          >
            <a href="https://gpts.gkscrm.com/" target="_blank">
              <Image
                src="/icons/a-1.svg"
                alt="数字人"
                width={40}
                height={40}
                className="mx-auto"
              />
              <p className="text-sm text-center">数字人</p>
            </a>
          </div>
          <div
            className={`w-full my-2 py-3 rounded-md text-center text-gray-900 dark:text-gray-500 bg-gray-50 dark:bg-gray-800 border border-slate-200 dark:border-slate-700`}
          >
            <a href="https://gpts.gkscrm.com/" target="_blank">
              <Image
                src="/icons/a-2.svg"
                alt="课程入驻"
                width={40}
                height={40}
                className="mx-auto"
              />
              <p className="text-sm text-center">课程入驻</p>
            </a>
          </div>
          <div
            className={`w-full my-2 py-3 rounded-md text-center text-gray-900 dark:text-gray-500 bg-gray-50 dark:bg-gray-800 border border-slate-200 dark:border-slate-700`}
          >
            <a href="https://gpts.gkscrm.com/" target="_blank">
              <Image
                src="/icons/a-3.svg"
                alt="加入分销"
                width={50}
                height={50}
                className="mx-auto"
              />
              <p className="text-sm text-center">加入分销</p>
            </a>
          </div>
          <div
            className={`w-full my-2 py-3 rounded-md text-center text-gray-900 dark:text-gray-500 bg-gray-50 dark:bg-gray-800 border border-slate-200 dark:border-slate-700`}
          >
            <a href="https://gpts.gkscrm.com/" target="_blank">
              <Image
                src="/icons/a-4.svg"
                alt="小程序推广"
                width={40}
                height={40}
                className="mx-auto"
              />
              <p className="text-sm text-center">小程序推广</p>
            </a>
          </div>
          <div
            className={`w-full my-2 py-3 rounded-md text-center text-gray-900 dark:text-gray-500 bg-gray-50 dark:bg-gray-800 border border-slate-200 dark:border-slate-700`}
          >
            <a href="https://gpts.gkscrm.com/" target="_blank">
              <Image
                src="/icons/a-5.svg"
                alt="电商带货"
                width={40}
                height={40}
                className="mx-auto"
              />
              <p className="text-sm text-center">电商带货</p>
            </a>
          </div>
          <div
            className={`w-full my-2 py-3 rounded-md text-center text-gray-900 dark:text-gray-500 bg-gray-50 dark:bg-gray-800 border border-slate-200 dark:border-slate-700`}
          >
            <a href="https://gpts.gkscrm.com/" target="_blank">
              <Image
                src="/icons/a-6.svg"
                alt="生财有道 - 副业圈子"
                width={40}
                height={40}
                className="mx-auto"
              />
              <p className="text-sm text-center">生财有道</p>
              <p className="text-sm text-center">副业圈子</p>
            </a>
          </div>
        </div>
      </div>
    </>
  );
}
